@@ -1,5 +1,9 @@
 #if MAC_OS_X_VERSION_10_5 <= MAC_OS_X_VERSION_MAX_ALLOWED
 
+/* Needed when building against the OS X 10.5+ SDK but running on 10.4. */
+#pragma weak CFFileDescriptorCreate
+#pragma weak CFFileDescriptorGetContext
+
 static void* 
 mod_filedescr_retain(void* info) 
 {
@@ -40,8 +44,8 @@ mod_CFFileDescriptorCallBack(
 		@encode(CFOptionFlags), &callBackType);
 
 	PyObject* result = PyObject_CallFunction(
-		PyTuple_GET_ITEM(info, 0),
-		"NNO", py_f, py_callBackType, PyTuple_GET_ITEM(info, 1));
+		PyTuple_GetItem(info, 0),
+		"NNO", py_f, py_callBackType, PyTuple_GetItem(info, 1));
 	if (result == NULL) {
 		PyObjCErr_ToObjCWithGILState(&state);
 	}
@@ -157,8 +161,8 @@ mod_CFFileDescriptorGetContext(
 		return NULL;
 	}
 
-	Py_INCREF(PyTuple_GET_ITEM((PyObject*)context.info, 1));
-	return PyTuple_GET_ITEM((PyObject*)context.info, 1);
+	Py_INCREF(PyTuple_GetItem((PyObject*)context.info, 1));
+	return PyTuple_GetItem((PyObject*)context.info, 1);
 }
 #endif
 
@@ -175,3 +179,15 @@ mod_CFFileDescriptorGetContext(
 		METH_VARARGS,		\
 		NULL		\
 	},
+
+#define COREFOUNDATION_FILEDESCRIPTOR_AFTER_CREATE		\
+	if (&CFFileDescriptorCreate == NULL) {  /* weakly linked */		\
+		if (PyObject_DelAttrString(m, "CFFileDescriptorCreate") == -1) {		\
+			PyObjC_INITERROR();		\
+		}		\
+	}		\
+	if (&CFFileDescriptorGetContext == NULL) {  /* weakly linked */		\
+		if (PyObject_DelAttrString(m, "CFFileDescriptorGetContext") == -1) {		\
+			PyObjC_INITERROR();		\
+		}		\
+	}
