@@ -1,3 +1,4 @@
+#define PY_SSIZE_T_CLEAN
 #include <Python.h>
 #include "pyobjc-api.h"
 
@@ -14,6 +15,7 @@
 #include "_Foundation_nscoder.m"
 #include "_Foundation_string.m"
 #include "_Foundation_typecode.m"
+#include "_Foundation_protocols.m"
 
 static PyMethodDef mod_methods[] = {
 	FOUNDATION_TYPECODE_METHODS
