@@ -1,6 +1,13 @@
 from PyObjCTools.TestSupport import *
 import time
 from CoreFoundation import *
+from Foundation import NSDate
+
+
+try:
+    long
+except NameError:
+    long = int
 
 
 class TestDate (TestCase):
@@ -11,6 +18,7 @@ class TestDate (TestCase):
     def testTypeID(self):
         v = CFDateGetTypeID()
         self.assertIsInstance(v, (int, long))
+
     def testConstants(self):
         self.assertIsInstance(kCFAbsoluteTimeIntervalSince1970, float)
         self.assertIsInstance(kCFAbsoluteTimeIntervalSince1904, float)
@@ -21,6 +29,7 @@ class TestDate (TestCase):
         self.assertEqual(kCFGregorianUnitsMinutes , (1 << 4))
         self.assertEqual(kCFGregorianUnitsSeconds , (1 << 5))
         self.assertEqual(kCFGregorianAllUnits , 0x00FFFFFF)
+
     def testStructs(self):
         v = CFGregorianDate()
         self.assertHasAttr(v, 'year')
@@ -29,6 +38,7 @@ class TestDate (TestCase):
         self.assertHasAttr(v, 'hour')
         self.assertHasAttr(v, 'minute')
         self.assertHasAttr(v, 'second')
+
         v = CFGregorianUnits()
         self.assertHasAttr(v, 'years')
         self.assertHasAttr(v, 'months')
@@ -36,19 +46,22 @@ class TestDate (TestCase):
         self.assertHasAttr(v, 'hours')
         self.assertHasAttr(v, 'minutes')
         self.assertHasAttr(v, 'seconds')
+
     def testAbsoluteTime(self):
         v = CFAbsoluteTimeGetCurrent()
         self.assertIsInstance(v, float)
         self.assertLessThan(abs(v - time.time() + kCFAbsoluteTimeIntervalSince1970) , 1.0)
+
     def testCreation(self):
         now = CFAbsoluteTimeGetCurrent()
         dt = CFDateCreate(None, now)
-        self.assertIsInstance(dt, CFDateRef)
+        self.assertIsInstance(dt, NSDate)
+
     def testInspection(self):
         now = CFAbsoluteTimeGetCurrent()
         nowtm = time.localtime()
         dt = CFDateCreate(None, now)
-        self.assertIsInstance(dt, CFDateRef)
+        self.assertIsInstance(dt, NSDate)
         self.assertEqual(CFDateGetAbsoluteTime(dt) , now)
         dt2 = CFDateCreate(None, now + 1000)
         self.assertEqual(CFDateGetTimeIntervalSinceDate(dt2, dt) , 1000)
@@ -83,5 +96,6 @@ class TestDate (TestCase):
         self.assertEqual(v , nowtm.tm_yday)
         v = CFAbsoluteTimeGetWeekOfYear(now, tz)
         self.assertIsInstance(v, (int, long))
+
 if __name__ == "__main__":
     main()
