@@ -1,6 +1,17 @@
 from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+
+try:
+    long
+except NameError:
+    long = int
+
 
 class TestNumberFormatter (TestCase):
     def testTypes(self):
@@ -8,6 +19,7 @@ class TestNumberFormatter (TestCase):
 
     def testTypeID(self):
         self.assertIsInstance(CFNumberFormatterGetTypeID(), (int, long))
+
     def testFuncs(self):
         locale = CFLocaleCopyCurrent()
         fmt = CFNumberFormatterCreate(None, locale, kCFNumberFormatterDecimalStyle)
@@ -23,20 +35,20 @@ class TestNumberFormatter (TestCase):
         self.assertEqual(v2 , v[:-2])
         v = CFNumberFormatterCreateStringWithNumber(None, fmt, 42.5)
         self.assertIsInstance(v, unicode)
-        self.assertEqual(v , u'42.5')
-        num, rng = CFNumberFormatterCreateNumberFromString(None, fmt, u"42.0a", (0, 5), 0)
+        self.assertEqual(v , b'42.5'.decode('ascii'))
+        num, rng = CFNumberFormatterCreateNumberFromString(None, fmt, b"42.0a".decode('ascii'), (0, 5), 0)
         self.assertEqual(num , 42.0)
         self.assertEqual(rng , (0, 4))
-        num, rng = CFNumberFormatterCreateNumberFromString(None, fmt, u"42.0a", (0, 5), kCFNumberFormatterParseIntegersOnly)
+        num, rng = CFNumberFormatterCreateNumberFromString(None, fmt, b"42.0a".decode('ascii'), (0, 5), kCFNumberFormatterParseIntegersOnly)
         self.assertEqual(num , 42)
         self.assertEqual(rng , (0, 2))
         v = CFNumberFormatterCopyProperty(fmt, kCFNumberFormatterCurrencyCode)
         self.assertIsInstance(v, unicode)
-        CFNumberFormatterSetProperty(fmt, kCFNumberFormatterCurrencyCode, u"HFL")
+        CFNumberFormatterSetProperty(fmt, kCFNumberFormatterCurrencyCode, b"HFL".decode('ascii'))
 
         self.assertResultIsCFRetained(CFNumberFormatterCopyProperty)
         v = CFNumberFormatterCopyProperty(fmt, kCFNumberFormatterCurrencyCode)
-        self.assertEqual(v , u"HFL")
+        self.assertEqual(v , b"HFL".decode('ascii'))
         self.assertArgIsOut(CFNumberFormatterGetDecimalInfoForCurrencyCode, 1)
         self.assertArgIsOut(CFNumberFormatterGetDecimalInfoForCurrencyCode, 2)
         ok, frac, rnd = CFNumberFormatterGetDecimalInfoForCurrencyCode("EUR", None, None)
@@ -44,27 +56,29 @@ class TestNumberFormatter (TestCase):
         self.assertEqual(frac, 2)
         self.assertEqual(rnd, 0.0)
 
-
-
     def testConstants(self):
-        self.assertEqual(kCFNumberFormatterNoStyle , 0)
-        self.assertEqual(kCFNumberFormatterDecimalStyle , 1)
-        self.assertEqual(kCFNumberFormatterCurrencyStyle , 2)
-        self.assertEqual(kCFNumberFormatterPercentStyle , 3)
-        self.assertEqual(kCFNumberFormatterScientificStyle , 4)
-        self.assertEqual(kCFNumberFormatterSpellOutStyle , 5)
-        self.assertEqual(kCFNumberFormatterParseIntegersOnly , 1)
-        self.assertEqual(kCFNumberFormatterRoundCeiling , 0)
-        self.assertEqual(kCFNumberFormatterRoundFloor , 1)
-        self.assertEqual(kCFNumberFormatterRoundDown , 2)
-        self.assertEqual(kCFNumberFormatterRoundUp , 3)
-        self.assertEqual(kCFNumberFormatterRoundHalfEven , 4)
-        self.assertEqual(kCFNumberFormatterRoundHalfDown , 5)
-        self.assertEqual(kCFNumberFormatterRoundHalfUp , 6)
-        self.assertEqual(kCFNumberFormatterPadBeforePrefix , 0)
-        self.assertEqual(kCFNumberFormatterPadAfterPrefix , 1)
-        self.assertEqual(kCFNumberFormatterPadBeforeSuffix , 2)
-        self.assertEqual(kCFNumberFormatterPadAfterSuffix , 3)
+        self.assertEqual(kCFNumberFormatterNoStyle, 0)
+        self.assertEqual(kCFNumberFormatterDecimalStyle, 1)
+        self.assertEqual(kCFNumberFormatterCurrencyStyle, 2)
+        self.assertEqual(kCFNumberFormatterPercentStyle, 3)
+        self.assertEqual(kCFNumberFormatterScientificStyle, 4)
+        self.assertEqual(kCFNumberFormatterSpellOutStyle, 5)
+
+        self.assertEqual(kCFNumberFormatterParseIntegersOnly, 1)
+
+        self.assertEqual(kCFNumberFormatterRoundCeiling, 0)
+        self.assertEqual(kCFNumberFormatterRoundFloor, 1)
+        self.assertEqual(kCFNumberFormatterRoundDown, 2)
+        self.assertEqual(kCFNumberFormatterRoundUp, 3)
+        self.assertEqual(kCFNumberFormatterRoundHalfEven, 4)
+        self.assertEqual(kCFNumberFormatterRoundHalfDown, 5)
+        self.assertEqual(kCFNumberFormatterRoundHalfUp, 6)
+
+        self.assertEqual(kCFNumberFormatterPadBeforePrefix, 0)
+        self.assertEqual(kCFNumberFormatterPadAfterPrefix, 1)
+        self.assertEqual(kCFNumberFormatterPadBeforeSuffix, 2)
+        self.assertEqual(kCFNumberFormatterPadAfterSuffix, 3)
+
         self.assertIsInstance(kCFNumberFormatterCurrencyCode, unicode)
         self.assertIsInstance(kCFNumberFormatterDecimalSeparator, unicode)
         self.assertIsInstance(kCFNumberFormatterCurrencyDecimalSeparator, unicode)
@@ -98,6 +112,7 @@ class TestNumberFormatter (TestCase):
         self.assertIsInstance(kCFNumberFormatterNegativeSuffix, unicode)
         self.assertIsInstance(kCFNumberFormatterPerMillSymbol, unicode)
         self.assertIsInstance(kCFNumberFormatterInternationalCurrencySymbol, unicode)
+
     @min_os_level('10.5')
     def testConstants10_5(self):
         self.assertIsInstance(kCFNumberFormatterCurrencyGroupingSeparator, unicode)
@@ -105,5 +120,6 @@ class TestNumberFormatter (TestCase):
         self.assertIsInstance(kCFNumberFormatterUseSignificantDigits, unicode)
         self.assertIsInstance(kCFNumberFormatterMinSignificantDigits, unicode)
         self.assertIsInstance(kCFNumberFormatterMaxSignificantDigits, unicode)
+
 if __name__ == "__main__":
     main()
