@@ -2,17 +2,24 @@ from PyObjCTools.TestSupport import *
 from CoreFoundation import *
 
 
+try:
+    long
+except NameError:
+    long = int
+
+
 class TestSet (TestCase):
     def testTypes(self):
         self.assertIsCFType(CFSetRef)
 
     def testTypeID(self):
         self.assertIsInstance(CFSetGetTypeID(), (int, long))
+
     def testCreation(self):
-        st = CFSetCreate(None, [u"a", u"b", u"c"], 3, kCFTypeSetCallBacks)
+        st = CFSetCreate(None, [b"a".decode('ascii'), b"b".decode('ascii'), b"c".decode('ascii')], 3, kCFTypeSetCallBacks)
         self.assertIsInstance(st, CFSetRef)
         self.assertIsInstance(st, objc.lookUpClass('NSSet'))
-        st = CFSetCreate(None, [u"a", u"b", u"c"], 3, kCFTypeSetCallBacks)
+        st = CFSetCreate(None, [b"a".decode('ascii'), b"b".decode('ascii'), b"c".decode('ascii')], 3, kCFTypeSetCallBacks)
         self.assertIsInstance(st, CFSetRef)
         st = CFSetCreateMutable(None, 0, kCFTypeSetCallBacks)
         self.assertIsInstance(st, CFSetRef)
@@ -20,40 +27,42 @@ class TestSet (TestCase):
         self.assertIsInstance(st, CFSetRef)
         cp = CFSetCreateCopy(None, st)
         self.assertIsInstance(st, CFSetRef)
+
     def testInspection(self):
-        st = CFSetCreate(None, [u"a", u"b", u"c"], 3, kCFTypeSetCallBacks)
+        st = CFSetCreate(None, [b"a".decode('ascii'), b"b".decode('ascii'), b"c".decode('ascii')], 3, kCFTypeSetCallBacks)
         self.assertIsInstance(st, CFSetRef)
         self.assertIsInstance(st, objc.lookUpClass('NSSet'))
         v = CFSetGetCount(st)
         self.assertEqual(v , 3)
         self.assertArgHasType(CFSetGetCountOfValue, 1, b'@')
-        v = CFSetGetCountOfValue(st, u'd')
+        v = CFSetGetCountOfValue(st, b'd'.decode('ascii'))
         self.assertEqual(v , 0)
-        v = CFSetGetCountOfValue(st, u'b')
+        v = CFSetGetCountOfValue(st, b'b'.decode('ascii'))
         self.assertEqual(v , 1)
         self.assertArgHasType(CFSetContainsValue, 1, b'@')
-        v = CFSetContainsValue(st, u'd')
+        v = CFSetContainsValue(st, b'd'.decode('ascii'))
         self.assertIs(v, False)
-        v = CFSetContainsValue(st, u'b')
+        v = CFSetContainsValue(st, b'b'.decode('ascii'))
         self.assertIs(v, True)
         self.assertResultHasType(CFSetGetValue, b'@')
         self.assertArgHasType(CFSetGetValue, 1, b'@')
-        v = CFSetGetValue(st, u'd')
+        v = CFSetGetValue(st, b'd'.decode('ascii'))
         self.assertIs(v, None)
-        v = CFSetGetValue(st, u'b')
-        self.assertEqual(v , u'b')
+        v = CFSetGetValue(st, b'b'.decode('ascii'))
+        self.assertEqual(v , b'b'.decode('ascii'))
         self.assertResultIsBOOL(CFSetGetValueIfPresent)
         self.assertArgHasType(CFSetGetValueIfPresent, 1, b'@')
         self.assertArgHasType(CFSetGetValueIfPresent, 2, b'o^@')
-        present, value = CFSetGetValueIfPresent(st, u'c', None)
+        present, value = CFSetGetValueIfPresent(st, b'c'.decode('ascii'), None)
         self.assertIs(present, True)
-        self.assertEqual(value , u'c')
+        self.assertEqual(value , b'c'.decode('ascii'))
         values = CFSetGetValues(st, None)
         values = list(values)
         values.sort()
-        self.assertEqual(values , [u'a', u'b', u'c'])
+        self.assertEqual(values , [b'a'.decode('ascii'), b'b'.decode('ascii'), b'c'.decode('ascii')])
+
     def testApplying(self):
-        st = CFSetCreate(None, [u"a", u"b", u"c"], 3, kCFTypeSetCallBacks)
+        st = CFSetCreate(None, [b"a".decode('ascii'), b"b".decode('ascii'), b"c".decode('ascii')], 3, kCFTypeSetCallBacks)
         self.assertIsInstance(st, CFSetRef)
         self.assertIsInstance(st, objc.lookUpClass('NSSet'))
         context = []
@@ -65,10 +74,10 @@ class TestSet (TestCase):
         CFSetApplyFunction(st, callback, context)
         self.assertEqual(len(context) , 3)
         context.sort()
-        self.assertEqual(context , [u'a', u'b', u'c'])
+        self.assertEqual(context , [b'a'.decode('ascii'), b'b'.decode('ascii'), b'c'.decode('ascii')])
 
     def testMutation(self):
-        st = CFSetCreate(None, [u"a", u"b", u"c"], 3, kCFTypeSetCallBacks)
+        st = CFSetCreate(None, [b"a".decode('ascii'), b"b".decode('ascii'), b"c".decode('ascii')], 3, kCFTypeSetCallBacks)
         self.assertIsInstance(st, CFSetRef)
         self.assertIsInstance(st, objc.lookUpClass('NSSet'))
         st = CFSetCreateMutableCopy(None, 0, st)
@@ -90,6 +99,5 @@ class TestSet (TestCase):
         self.assertArgHasType(CFSetReplaceValue, 1, b'@')
         CFSetReplaceValue(st, 'd')
 
-
 if __name__ == "__main__":
     main()
