@@ -2,6 +2,11 @@ from Foundation import *
 from PyObjCTools.TestSupport import *
 import Foundation
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestHelper (NSObject):
     def incFoo_(self, foo):
         foo[0] += 1
@@ -76,6 +81,11 @@ class TestSubclassingUndo(TestCase):
         self.assertIsInstance(NSUndoManagerWillCloseUndoGroupNotification, unicode)
         self.assertEqual(NSUndoCloseGroupingRunLoopOrdering, 350000)
 
+    @min_os_level('10.7')
+    def testConstants10_7(self):
+        self.assertIsInstance(NSUndoManagerGroupIsDiscardableKey, unicode)
+        self.assertIsInstance(NSUndoManagerDidCloseUndoGroupNotification, unicode)
+
     def testMethods(self):
         self.assertResultIsBOOL(NSUndoManager.isUndoRegistrationEnabled)
         self.assertResultIsBOOL(NSUndoManager.groupsByEvent)
@@ -86,5 +96,11 @@ class TestSubclassingUndo(TestCase):
         self.assertResultIsBOOL(NSUndoManager.isRedoing)
         self.assertArgIsSEL(NSUndoManager.registerUndoWithTarget_selector_object_, 1, b'v@:@')
 
+    @min_os_level('10.7')
+    def testMethods10_7(self):
+        self.assertArgIsBOOL(NSUndoManager.setActionIsDiscardable_, 0)
+        self.assertResultIsBOOL(NSUndoManager.undoActionIsDiscardable)
+        self.assertResultIsBOOL(NSUndoManager.redoActionIsDiscardable)
+
 if __name__ == '__main__':
     main( )
